# gpg-qr

A simple tool to generate QR codes from GPG ascii keys and revoke certificates.Useful for printing out hardcopy.

## Options ##
1. Display in Terminal
2. Save as PNG
3. Upload PNG to TempFiles.org
4. Quit

## Installation ##
```python
pip install gpg-qr
```

## Note
This is the qrencode version with the following python dependencies:
qrcode, requests, pillow. Please install [qrencode](https://fukuchi.org/works/qrencode/) via your package manager.


## License ##
[GPL3](LICENSE)
